#!/usr/bin/env python
# -*- coding: UTF-8 -*-
'''
  File Name : grideye_cam.py

  2次元温度センサ、サーボモーターを使ったカメラ位置制御

  Ver.0.1 : 2016/11 初版

  開発環境 : Raspberry Pi
             Python 3.4.2
             Python 2.7.9

  CopyLeft 2016 Moo Soft (Akiyosi Yokoyama)
'''
import sys
import time
from moo_moveservo import MoveServo    # サーボモーター駆動クラス
from moo_grideye_i2c import GridEyeI2C # 2次元温度センサ操作クラス(I2C)

# ============================================== #
# メインループ
# ============================================== #
def loop():
    temptxt = '/home/pi/ram_disk/a.txt'                                            # 最高温度情報出力先
    try:
        gr = GridEyeI2C(addr=0x69, debug=True)                                     # 2次元温度センサ操作クラス(I2C)
        ms = MoveServo(fwait=2.0, fname=temptxt, addr=0x4f, frq=50)                # サーボモーター駆動クラス
        ms.start()                                                                 # 起動
        while True:
            tmax, trow, tcol, result = gr.get_temp()                               # 最高温度,最高温度行位置,最高温度列位置,温度文字列
            smax = '{0:+3.2f}'.format(tmax)
            gr.write_text(temptxt, '{0},{1},{2}'.format(trow, tcol, smax))         # 最高温度情報出力
            print('-' * 64)
            print('Max:{0} Row:{1} Col:{2}\n{3}'.format(smax, trow, tcol, result)) # 画面表示
            print('-' * 64)
            time.sleep(2.0)
    except KeyboardInterrupt as e:
        ms.servo.servo_between(ms.s0_ch, ms.s0_now, ms.s0_Center, ms.s0_Min, ms.s0_Max, ms.m_wait)
        ms.servo.servo_between(ms.s1_ch, ms.s1_now, ms.s1_Center, ms.s1_Min, ms.s1_Max, ms.m_wait)
        raise
    except Exception as e:
        print('loop:{0}'.format(e))

# ============================================== #
if __name__=='__main__':
    loop()
